@@ -4,7 +4,8 @@ from users_and_computers.models import RiskAssignment
 
 
 class RiskVMPanel(PluginTemplateExtension):
-    model = 'users_and_computers.Aduser'
+    # model = 'users_and_computers.Risk'
+    model = 'virtualization.virtualmachine'
 
     def right_page(self):
         vm = self.context['object']
@@ -25,13 +26,15 @@ class RiskVMPanel(PluginTemplateExtension):
 
 
 class RiskDevicePanel(PluginTemplateExtension):
-    model = 'dcim.device'
+    # model = 'users_and_computers.RiskRelation'
+    # model = 'dcim.device'
+    model = 'users_and_computers.risks'
 
     def right_page(self):
-        device = self.context['object']
-        content_type_id = ContentType.objects.get_for_model(model=device).id
+        risk = self.context['object']
+        content_type_id = ContentType.objects.get_for_model(model=risk).id
         risk_ass = RiskAssignment.objects.filter(
-            object_id=device.id, content_type=content_type_id)
+            object_id=risk.id, content_type=content_type_id)
         risks = []
         for r in risk_ass:
             risks.append({
